=== modified file 'drizzled/definition/cache.cc'
--- drizzled/definition/cache.cc	2011-02-26 16:03:36 +0000
+++ drizzled/definition/cache.cc	2011-04-13 13:04:50 +0000
@@ -31,9 +31,11 @@
 #include <drizzled/util/find_ptr.h>
 
 namespace drizzled {
-
 namespace definition {
 
+Cache::Map Cache::cache;
+boost::mutex Cache::_mutex;
+
 table::instance::Shared::shared_ptr Cache::find(const identifier::Table::Key &key)
 {
   boost::mutex::scoped_lock scopedLock(_mutex);
@@ -62,7 +64,7 @@
 {
   boost::mutex::scoped_lock scopedLock(_mutex);
 
-  vector.reserve(definition::Cache::singleton().size());
+  vector.reserve(definition::Cache::size());
 
   std::transform(cache.begin(),
                  cache.end(),

=== modified file 'drizzled/definition/cache.h'
--- drizzled/definition/cache.h	2011-03-29 10:15:45 +0000
+++ drizzled/definition/cache.h	2011-04-13 13:04:50 +0000
@@ -28,37 +28,30 @@
 class Cache
 {
 public:
-  static inline Cache &singleton()
-  {
-    static Cache open_cache;
-
-    return open_cache;
-  }
-
-  size_t size() const
-  {
+  static size_t size()
+  {
+    // no lock?
     return cache.size();
   }
 
-  void rehash(size_t arg)
+  static void rehash(size_t arg)
   {
+    // no lock?
     cache.rehash(arg);
   }
 
-  table::instance::Shared::shared_ptr find(const identifier::Table::Key &identifier);
-  void erase(const identifier::Table::Key &identifier);
-  bool insert(const identifier::Table::Key &identifier, table::instance::Shared::shared_ptr share);
-
-protected:
-  friend class drizzled::generator::TableDefinitionCache;
-
-  void CopyFrom(table::instance::Shared::vector &vector);
-
+  static table::instance::Shared::shared_ptr find(const identifier::Table::Key&);
+  static void erase(const identifier::Table::Key&);
+  static bool insert(const identifier::Table::Key&, table::instance::Shared::shared_ptr);
 private:
+  static void CopyFrom(table::instance::Shared::vector&);
+
   typedef boost::unordered_map< identifier::Table::Key, table::instance::Shared::shared_ptr> Map;
 
-  Map cache;
-  boost::mutex _mutex;
+  static Map cache;
+  static boost::mutex _mutex;
+
+  friend class generator::TableDefinitionCache;
 };
 
 } /* namespace definition */

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-04-13 11:05:41 +0000
+++ drizzled/drizzled.cc	2011-04-13 13:04:50 +0000
@@ -1548,7 +1548,7 @@
 
   // Resize the definition Cache at startup
   table::Cache::rehash(table_def_size);
-  definition::Cache::singleton().rehash(table_def_size);
+  definition::Cache::rehash(table_def_size);
   message::Cache::singleton().rehash(table_def_size);
 
   setup_fpu();

=== modified file 'drizzled/generator/table_definition_cache.h'
--- drizzled/generator/table_definition_cache.h	2011-03-14 05:40:28 +0000
+++ drizzled/generator/table_definition_cache.h	2011-04-13 13:04:50 +0000
@@ -34,7 +34,7 @@
 
   TableDefinitionCache()
   {
-    definition::Cache::singleton().CopyFrom(local_vector);
+    definition::Cache::CopyFrom(local_vector);
     iter= local_vector.begin();
   }
 

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-04-13 12:17:56 +0000
+++ drizzled/sql_table.cc	2011-04-13 13:04:50 +0000
@@ -1338,7 +1338,7 @@
       /*
         @todo improve this error condition.
       */
-      if (definition::Cache::singleton().find(identifier.getKey()))
+      if (definition::Cache::find(identifier.getKey()))
       {
         my_error(ER_TABLE_EXISTS_ERROR, identifier);
 

=== modified file 'drizzled/table/instance/base.cc'
--- drizzled/table/instance/base.cc	2011-04-09 16:11:46 +0000
+++ drizzled/table/instance/base.cc	2011-04-13 13:04:50 +0000
@@ -1520,7 +1520,7 @@
 
   NOTES
   This function is called when the table definition is not cached in
-  definition::Cache::singleton().getCache()
+  definition::Cache::getCache()
   The data is returned in 'share', which is alloced by
   alloc_table_share().. The code assumes that share is initialized.
 

=== modified file 'drizzled/table/instance/shared.cc'
--- drizzled/table/instance/shared.cc	2011-04-13 10:38:28 +0000
+++ drizzled/table/instance/shared.cc	2011-04-13 13:04:50 +0000
@@ -27,14 +27,9 @@
 #include <drizzled/table/instance/shared.h>
 #include <drizzled/plugin/storage_engine.h>
 
-namespace drizzled
-{
-
-namespace table
-{
-
-namespace instance
-{
+namespace drizzled {
+namespace table {
+namespace instance {
 
 Shared::Shared(const identifier::Table::Type type_arg,
                const identifier::Table &identifier,
@@ -124,7 +119,7 @@
   in_error= 0;
 
   /* Read table definition from cache */
-  if ((share= definition::Cache::singleton().find(identifier.getKey())))
+  if ((share= definition::Cache::find(identifier.getKey())))
     return foundTableShare(share);
   
   drizzled::message::schema::shared_ptr schema_message_ptr= plugin::StorageEngine::getSchemaDefinition(identifier);
@@ -147,7 +142,7 @@
   
   plugin::EventObserver::registerTableEvents(*share);
 
-  bool ret= definition::Cache::singleton().insert(identifier.getKey(), share);
+  bool ret= definition::Cache::insert(identifier.getKey(), share);
 
   if (not ret)
   {
@@ -195,7 +190,7 @@
 
   if (to_be_deleted)
   {
-    definition::Cache::singleton().erase(share->getCacheKey());
+    definition::Cache::erase(share->getCacheKey());
   }
 }
 
@@ -215,19 +210,19 @@
 
   if (to_be_deleted)
   {
-    definition::Cache::singleton().erase(share->getCacheKey());
+    definition::Cache::erase(share->getCacheKey());
   }
 }
 
 void release(const identifier::Table &identifier)
 {
-  TableShare::shared_ptr share= definition::Cache::singleton().find(identifier.getKey());
+  TableShare::shared_ptr share= definition::Cache::find(identifier.getKey());
   if (share)
   {
     share->resetVersion(); 
     if (share->getTableCount() == 0)
     {
-      definition::Cache::singleton().erase(identifier.getKey());
+      definition::Cache::erase(identifier.getKey());
     }
   }
 }

